# Finished

The experiment finished successfully.

- Time: `%(time)s`
- Log file: `%(logfile)s`

You can:

[Open log file](opensesame://event.after_experiment_open_logfile){: .important-button}<br />
[Open log-file folder](opensesame://event.after_experiment_open_logfile_folder){: .button}<br />
[Copy log file to file pool](opensesame://event.after_experiment_copy_logfile){: .button}
